@@ -1,7 +1,7 @@
 fn main() {
     let word = "silence";
 
-    let definition = webster::definition(word).unwrap();
+    let definition = webster::dictionary(word).unwrap();
 
     println!("{} definition: {}", word, definition);
 }
\ No newline at end of file
