@@ -1,7 +1,7 @@
 fn main() {
     let word = &std::env::args().collect::<Vec<_>>()[1].to_string();
 
-    let definition = webster::definition(word).unwrap();
-
+    let definition = webster::dictionary(word).unwrap();
+  
     println!("{}", definition);
 }
\ No newline at end of file
